/**
 * OW2 Util
 * Copyright (C) 2010-2011 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Activator.java 6136 2012-01-25 08:33:47Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.protocol.osgi.impl;

import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceRegistration;
import org.ow2.util.protocol.api.IProtocol;
import org.ow2.util.protocol.api.IProtocolConfigRegistry;
import org.ow2.util.protocol.api.IShellFormatter;
import org.ow2.util.protocol.impl.ProcessProtocol;
import org.ow2.util.protocol.impl.ProtocolConfigRegistryImpl;
import org.ow2.util.protocol.impl.shell.MsDosShellFormatter;
import org.ow2.util.protocol.impl.shell.ShShellFormatter;
import org.ow2.util.protocol.osgi.api.Constants;

/**
 *
 * @author Loris Bouzonnet
 */
public class Activator implements BundleActivator {

    private ServiceRegistration<IProtocol> processReg;

    private ServiceRegistration<IShellFormatter> shReg;

    private ServiceRegistration<IShellFormatter> msDosReg;

    private ServiceRegistration<IProtocolConfigRegistry> registryReg;

    public void start(final BundleContext context) throws Exception {

        final Dictionary<String, String> processProps = new Hashtable<String, String>();
        processProps.put(Constants.PROTOCOL_NAME, Constants.PROCESS_PROTOCOL);
        processReg = context.registerService(IProtocol.class, new ProcessProtocol(), processProps);

        final ShShellFormatter shFormatter = new ShShellFormatter();
        final Dictionary<String, String> shProps = new Hashtable<String, String>();
        shProps.put(Constants.SHELL_TYPE, "sh");
        shReg = context.registerService(IShellFormatter.class, shFormatter, shProps);

        final MsDosShellFormatter msDosFormatter = new MsDosShellFormatter();
        final Dictionary<String, String> msDosProps = new Hashtable<String, String>();
        msDosProps.put(Constants.SHELL_TYPE, "msdos");
        msDosReg = context.registerService(IShellFormatter.class, msDosFormatter, msDosProps);

        final ProtocolConfigRegistryImpl configRegistry = new ProtocolConfigRegistryImpl();
        registryReg = context.registerService(IProtocolConfigRegistry.class, configRegistry, null);

    }

    public void stop(final BundleContext context) throws Exception {

        if (processReg != null) {
            processReg.unregister();
        }
        if (shReg != null) {
            shReg.unregister();
        }
        if (msDosReg != null) {
            msDosReg.unregister();
        }
        if (registryReg != null) {
            registryReg.unregister();
        }
    }

}
